@@ -42,11 +42,19 @@ enum {
 	GMIME_MULTIPART_ENCRYPTED_CONTENT
 };
 
+
+/**
+ * GMimeMultipartEncrypted:
+ * @parent_object: parent #GMimeMultipart
+ * @validity: a #GMimeSignatureValidity if the part has been decrypted or %NULL otherwise
+ * @decrypted: cached decrypted MIME part
+ *
+ * A multipart/encrypted MIME part.
+ **/
 struct _GMimeMultipartEncrypted {
 	GMimeMultipart parent_object;
 	
-	char *protocol;
-	
+	GMimeSignatureValidity *validity;
 	GMimeObject *decrypted;
 };
 
@@ -61,13 +69,16 @@ GType g_mime_multipart_encrypted_get_type (void);
 GMimeMultipartEncrypted *g_mime_multipart_encrypted_new (void);
 
 int g_mime_multipart_encrypted_encrypt (GMimeMultipartEncrypted *mpe, GMimeObject *content,
-					GMimeCipherContext *ctx, GPtrArray *recipients,
+					GMimeCipherContext *ctx, gboolean sign,
+					const char *userid, GPtrArray *recipients,
 					GError **err);
 
 GMimeObject *g_mime_multipart_encrypted_decrypt (GMimeMultipartEncrypted *mpe,
 						 GMimeCipherContext *ctx,
 						 GError **err);
 
+const GMimeSignatureValidity *g_mime_multipart_encrypted_get_signature_validity (GMimeMultipartEncrypted *mpe);
+
 G_END_DECLS
 
 #endif /* __GMIME_MULTIPART_ENCRYPTED_H__ */
