@@ -78,8 +78,16 @@ static GMimeObject *parser_construct_multipart (GMimeParser *parser, ContentType
 
 static GObjectClass *parent_class = NULL;
 
-#define SCAN_BUF 4096		/* size of read buffer */
-#define SCAN_HEAD 128		/* headroom guaranteed to be before each read buffer */
+/* size of read buffer */
+#define SCAN_BUF 4096
+
+/* headroom guaranteed to be before each read buffer */
+#define SCAN_HEAD 128
+
+/* conservative growth sizes */
+#define HEADER_INIT_SIZE 128
+#define HEADER_RAW_INIT_SIZE 1024
+
 
 enum {
 	GMIME_PARSER_STATE_ERROR = -1,
@@ -327,13 +335,13 @@ parser_init (GMimeParser *parser, GMimeStream *stream)
 	priv->from_offset = -1;
 	priv->from_line = g_byte_array_new ();
 	
-	priv->headerbuf = g_malloc (SCAN_HEAD);
+	priv->headerbuf = g_malloc (HEADER_INIT_SIZE);
+	priv->headerleft = HEADER_INIT_SIZE - 1;
 	priv->headerptr = priv->headerbuf;
-	priv->headerleft = SCAN_HEAD - 1;
 	
-	priv->rawbuf = g_malloc (SCAN_HEAD);
+	priv->rawbuf = g_malloc (HEADER_RAW_INIT_SIZE);
+	priv->rawleft = HEADER_RAW_INIT_SIZE - 1;
 	priv->rawptr = priv->rawbuf;
-	priv->rawleft = SCAN_HEAD - 1;
 	
 	priv->headers_begin = -1;
 	priv->headers_end = -1;
@@ -378,11 +386,7 @@ parser_close (GMimeParser *parser)
 GMimeParser *
 g_mime_parser_new (void)
 {
-	GMimeParser *parser;
-	
-	parser = g_object_new (GMIME_TYPE_PARSER, NULL);
-	
-	return parser;
+	return g_object_newv (GMIME_TYPE_PARSER, 0, NULL);
 }
 
 
@@ -594,7 +598,7 @@ g_mime_parser_set_header_regex (GMimeParser *parser, const char *regex,
 
 
 static ssize_t
-parser_fill (GMimeParser *parser)
+parser_fill (GMimeParser *parser, size_t atleast)
 {
 	struct _GMimeParserPrivate *priv = parser->priv;
 	char *inbuf, *inptr, *inend;
@@ -608,6 +612,9 @@ parser_fill (GMimeParser *parser)
 	
 	g_assert (inptr <= inend);
 	
+	if (inlen > atleast)
+		return inlen;
+	
 	/* attempt to align 'inend' with realbuf + SCAN_HEAD */
 	if (inptr >= inbuf) {
 		inbuf -= inlen < SCAN_HEAD ? inlen : SCAN_HEAD;
@@ -628,12 +635,12 @@ parser_fill (GMimeParser *parser)
 	
 	priv->inptr = inptr;
 	priv->inend = inbuf;
-	inend = priv->realbuf + SCAN_HEAD + SCAN_BUF - 1;
+	inend = priv->realbuf + SCAN_HEAD + SCAN_BUF;
 	
-	if ((nread = g_mime_stream_read (priv->stream, inbuf, inend - inbuf)) > 0)
+	if ((nread = g_mime_stream_read (priv->stream, inbuf, inend - inbuf)) > 0) {
+		priv->offset += nread;
 		priv->inend += nread;
-	
-	priv->offset = g_mime_stream_tell (priv->stream);
+	}
 	
 	return priv->inend - priv->inptr;
 }
@@ -659,7 +666,7 @@ parser_offset (struct _GMimeParserPrivate *priv, const char *inptr)
  * Gets the current stream offset from the parser's internal stream.
  *
  * Returns: the current stream offset from the parser's internal stream
- * or -1 on error.
+ * or %-1 on error.
  **/
 gint64
 g_mime_parser_tell (GMimeParser *parser)
@@ -673,7 +680,7 @@ g_mime_parser_tell (GMimeParser *parser)
 
 /**
  * g_mime_parser_eos:
- * @parser: MIME parser
+ * @parser: a #GMimeParser context
  *
  * Tests the end-of-stream indicator for @parser's internal stream.
  *
@@ -707,7 +714,7 @@ parser_step_from (GMimeParser *parser)
 	
 	do {
 	refill:
-		if (parser_fill (parser) <= left) {
+		if (parser_fill (parser, MAX (SCAN_HEAD, left)) <= left) {
 			/* failed to find a From line; EOF reached */
 			priv->state = GMIME_PARSER_STATE_ERROR;
 			priv->inptr = priv->inend;
@@ -753,7 +760,8 @@ parser_step_from (GMimeParser *parser)
 	return 0;
 }
 
-static size_t
+#ifdef ALLOC_NEAREST_POW2
+static inline size_t
 nearest_pow (size_t num)
 {
 	size_t n = num > 0 ? num - 1 : 0;
@@ -768,12 +776,21 @@ nearest_pow (size_t num)
 	return n;
 }
 
+#define next_alloc_size(n) nearest_pow (n)
+#else
+static inline size_t
+next_alloc_size (size_t n)
+{
+	return ((n + 63) / 64) * 64;
+}
+#endif
+
 #define header_append(priv, start, len) G_STMT_START {                    \
 	if (priv->headerleft <= len) {                                    \
 		size_t hlen, hoff;                                        \
 		                                                          \
 		hoff = priv->headerptr - priv->headerbuf;                 \
-		hlen = nearest_pow (hoff + len + 1);                      \
+		hlen = next_alloc_size (hoff + len + 1);                  \
 		                                                          \
 		priv->headerbuf = g_realloc (priv->headerbuf, hlen);      \
 		priv->headerptr = priv->headerbuf + hoff;                 \
@@ -790,7 +807,7 @@ nearest_pow (size_t num)
 		size_t hlen, hoff;                                        \
 		                                                          \
 		hoff = priv->rawptr - priv->rawbuf;                       \
-		hlen = nearest_pow (hoff + len + 1);                      \
+		hlen = next_alloc_size (hoff + len + 1);                  \
 		                                                          \
 		priv->rawbuf = g_realloc (priv->rawbuf, hlen);            \
 		priv->rawptr = priv->rawbuf + hoff;                       \
@@ -896,7 +913,7 @@ parser_step_headers (GMimeParser *parser)
 	
 	do {
 	refill:
-		if (parser_fill (parser) <= left)
+		if (parser_fill (parser, MAX (SCAN_HEAD, left)) <= left)
 			break;
 		
 		inptr = priv->inptr;
@@ -1118,7 +1135,7 @@ parser_skip_line (GMimeParser *parser)
 		
 		priv->inptr = inptr;
 		
-		if (parser_fill (parser) <= 0) {
+		if (parser_fill (parser, SCAN_HEAD) <= 0) {
 			inptr = priv->inptr;
 			rv = -1;
 			break;
@@ -1229,7 +1246,7 @@ check_boundary (struct _GMimeParserPrivate *priv, const char *start, size_t len)
 		d(printf ("'%.*s' not a boundary\n", len, start));
 	}
 	
-	return 0;
+	return FOUND_NOTHING;
 }
 
 /* Optimization Notes:
@@ -1242,6 +1259,10 @@ check_boundary (struct _GMimeParserPrivate *priv, const char *start, size_t len)
  * job correctly ;-)
  **/
 
+
+/* we add 2 for \r\n */
+#define MAX_BOUNDARY_LEN(bounds) (bounds ? bounds->boundarylenmax + 2 : 0)
+
 static int
 parser_scan_content (GMimeParser *parser, GByteArray *content, int *crlf)
 {
@@ -1249,6 +1270,7 @@ parser_scan_content (GMimeParser *parser, GByteArray *content, int *crlf)
 	register char *inptr;
 	char *start, *inend;
 	size_t nleft, len;
+	size_t atleast;
 	int found = 0;
 	
 	d(printf ("scan-content\n"));
@@ -1259,10 +1281,13 @@ parser_scan_content (GMimeParser *parser, GByteArray *content, int *crlf)
 	
 	start = inptr = priv->inptr;
 	
+	/* figure out minimum amount of data we need */
+	atleast = MAX (SCAN_HEAD, MAX_BOUNDARY_LEN (priv->bounds));
+	
 	do {
 	refill:
 		nleft = priv->inend - inptr;
-		if (parser_fill (parser) <= 0) {
+		if (parser_fill (parser, atleast) <= 0) {
 			start = priv->inptr;
 			found = FOUND_EOS;
 			break;
