@@ -43,6 +43,14 @@ G_BEGIN_DECLS
 typedef struct _GMimeParser GMimeParser;
 typedef struct _GMimeParserClass GMimeParserClass;
 
+
+/**
+ * GMimeParser:
+ * @parent_object: parent #GObject
+ * @priv: private parser state
+ *
+ * A MIME parser context.
+ **/
 struct _GMimeParser {
 	GObject parent_object;
 	
@@ -102,6 +110,8 @@ gboolean g_mime_parser_eos (GMimeParser *parser);
 char *g_mime_parser_get_from (GMimeParser *parser);
 
 gint64 g_mime_parser_get_from_offset (GMimeParser *parser);
+gint64 g_mime_parser_get_headers_begin (GMimeParser *parser);
+gint64 g_mime_parser_get_headers_end (GMimeParser *parser);
 
 G_END_DECLS
 
