@@ -276,20 +276,19 @@ stream_substream (GMimeStream *stream, gint64 start, gint64 end)
 {
 	GMimeStreamMem *mem;
 	
-	mem = g_object_new (GMIME_TYPE_STREAM_MEM, NULL);
-	mem->owner = FALSE;
+	mem = g_object_newv (GMIME_TYPE_STREAM_MEM, 0, NULL);
+	g_mime_stream_construct ((GMimeStream *) mem, start, end);
 	mem->buffer = GMIME_STREAM_MEM (stream)->buffer;
+	mem->owner = FALSE;
 	
-	g_mime_stream_construct (GMIME_STREAM (mem), start, end);
-	
-	return GMIME_STREAM (mem);
+	return (GMimeStream *) mem;
 }
 
 
 /**
  * g_mime_stream_mem_new:
  *
- * Creates a new GMimeStreamMem object.
+ * Creates a new #GMimeStreamMem object.
  *
  * Returns: a new memory stream.
  **/
@@ -298,13 +297,12 @@ g_mime_stream_mem_new (void)
 {
 	GMimeStreamMem *mem;
 	
-	mem = g_object_new (GMIME_TYPE_STREAM_MEM, NULL);
+	mem = g_object_newv (GMIME_TYPE_STREAM_MEM, 0, NULL);
+	g_mime_stream_construct ((GMimeStream *) mem, 0, -1);
 	mem->buffer = g_byte_array_new ();
 	mem->owner = TRUE;
 	
-	g_mime_stream_construct (GMIME_STREAM (mem), 0, -1);
-	
-	return GMIME_STREAM (mem);
+	return (GMimeStream *) mem;
 }
 
 
@@ -312,7 +310,7 @@ g_mime_stream_mem_new (void)
  * g_mime_stream_mem_new_with_byte_array:
  * @array: source data
  *
- * Creates a new GMimeStreamMem with data @array.
+ * Creates a new #GMimeStreamMem with data @array.
  *
  * Returns: a new memory stream using @array.
  **/
@@ -321,22 +319,21 @@ g_mime_stream_mem_new_with_byte_array (GByteArray *array)
 {
 	GMimeStreamMem *mem;
 	
-	mem = g_object_new (GMIME_TYPE_STREAM_MEM, NULL);
-	mem->owner = TRUE;
+	mem = g_object_newv (GMIME_TYPE_STREAM_MEM, 0, NULL);
+	g_mime_stream_construct ((GMimeStream *) mem, 0, -1);
 	mem->buffer = array;
+	mem->owner = TRUE;
 	
-	g_mime_stream_construct (GMIME_STREAM (mem), 0, -1);
-	
-	return GMIME_STREAM (mem);
+	return (GMimeStream *) mem;
 }
 
 
 /**
  * g_mime_stream_mem_new_with_buffer:
  * @buffer: stream data
- * @len: data length
+ * @len: buffer length
  *
- * Creates a new GMimeStreamMem object and initializes the stream
+ * Creates a new #GMimeStreamMem object and initializes the stream
  * contents with the first @len bytes of @buffer.
  *
  * Returns: a new memory stream initialized with @buffer.
@@ -346,21 +343,20 @@ g_mime_stream_mem_new_with_buffer (const char *buffer, size_t len)
 {
 	GMimeStreamMem *mem;
 	
-	mem = g_object_new (GMIME_TYPE_STREAM_MEM, NULL);
-	mem->owner = TRUE;
+	mem = g_object_newv (GMIME_TYPE_STREAM_MEM, 0, NULL);
+	g_mime_stream_construct ((GMimeStream *) mem, 0, -1);
 	mem->buffer = g_byte_array_new ();
+	mem->owner = TRUE;
 	
 	g_byte_array_append (mem->buffer, (unsigned char *) buffer, len);
 	
-	g_mime_stream_construct (GMIME_STREAM (mem), 0, -1);
-	
-	return GMIME_STREAM (mem);
+	return (GMimeStream *) mem;
 }
 
 
 /**
  * g_mime_stream_mem_get_byte_array:
- * @mem: memory stream
+ * @mem: a #GMimeStreamMem
  *
  * Gets the byte array from the memory stream.
  *
@@ -377,7 +373,7 @@ g_mime_stream_mem_get_byte_array (GMimeStreamMem *mem)
 
 /**
  * g_mime_stream_mem_set_byte_array:
- * @mem: memory stream
+ * @mem: a #GMimeStreamMem
  * @array: stream data
  *
  * Sets the byte array on the memory stream.
@@ -409,7 +405,7 @@ g_mime_stream_mem_set_byte_array (GMimeStreamMem *mem, GByteArray *array)
 
 /**
  * g_mime_stream_mem_get_owner:
- * @mem: memory stream
+ * @mem: a #GMimeStreamMem
  *
  * Gets whether or not @mem owns the backend memory buffer.
  *
@@ -427,7 +423,7 @@ g_mime_stream_mem_get_owner (GMimeStreamMem *mem)
 
 /**
  * g_mime_stream_mem_set_owner:
- * @mem: memory stream
+ * @mem: a #GMimeStreamMem
  * @owner: owner
  *
  * Sets whether or not @mem owns the backend memory buffer.
